@@ -25,8 +25,7 @@ void
 builder_config_save (void)
 {
   /* save UI stuff */
-  gnome_db_save_window_config("MainWindow",
-                              gnome_db_container_get_widget(GNOME_DB_CONTAINER(glb_mainwin)));
+  gnome_db_save_window_config("MainWindow", glb_mainwin);
 
   gda_config_commit();
 }
\ No newline at end of file
