@@ -28,13 +28,14 @@ typedef struct
 
 static void select_provider_cb (GtkMenuItem *item, gpointer data);
 
+static void save_log_file          (GtkWidget *w, GnomeDbControlInstance *control_instance);
 static void view_selected_entry_cb (GtkWidget *w, GnomeDbControlInstance *control_instance);
 
 static GnomeDbControl* log_control = NULL;
 static GnomeUIInfo log_control_toolbar[] =
 {
   { GNOME_APP_UI_ITEM, N_("Save"), N_("Save log to a disk file"),
-    NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    save_log_file, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_PIXMAP_SAVE, 0, 0, NULL },
   { GNOME_APP_UI_ITEM, N_("View"), N_("View selected log entry"),
     view_selected_entry_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
@@ -127,6 +128,27 @@ select_provider_cb (GtkMenuItem *item, gpointer data)
     }
 }
 
+static void
+save_log_file (GtkWidget *w, GnomeDbControlInstance *control_instance)
+{
+  COMPONENTS_LogInfo* log_info;
+  
+  g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
+  
+  log_info = (COMPONENTS_LogInfo *) gnome_db_control_instance_get_user_data(control_instance);
+  if (log_info)
+    {
+      gchar* filename;
+      
+      filename = gnome_db_select_file(_("Save Log File"));
+      if (filename)
+        {
+          gnome_db_log_viewer_save(GNOME_DB_LOG_VIEWER(log_info->viewer), filename);
+          g_free((gpointer) filename);
+        }
+    }
+}
+
 static void
 view_selected_entry_cb (GtkWidget *w, GnomeDbControlInstance *control_instance)
 {
