@@ -1,19 +1,19 @@
 /* GNOME DB Front End
  * Copyright (C) 2000 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "gnomedb-fe.h"
@@ -165,3 +165,24 @@ fe_workarea_get_current_tab (void)
   return gtk_notebook_get_nth_page(GTK_NOTEBOOK(workarea_notebook), tab);
 }
 
+void
+fe_workarea_remove_tab (GtkWidget *tab)
+{
+  gint       page_num;
+  GtkWidget* wid;
+  
+  g_return_if_fail(GTK_IS_NOTEBOOK(workarea_notebook));
+  g_return_if_fail(GTK_IS_WIDGET(tab));
+  
+  /* deactivate this component */
+  page_num = gtk_notebook_page_num(GTK_NOTEBOOK(workarea_notebook), tab);
+  gtk_notebook_remove_page(GTK_NOTEBOOK(workarea_notebook), page_num);
+  gnome_db_control_widget_deactivate(GNOME_DB_CONTROL_WIDGET(tab));
+  
+  /* activate the new component */
+  wid = fe_workarea_get_current_tab();
+  if (GTK_IS_WIDGET(wid))
+    {
+      //gnome_db_control_widget_activate(GNOME_DB_CONTROL_WIDGET(wid));
+    }
+}
