@@ -51,6 +51,7 @@ GtkWidget* fe_workarea_create          (void);
 void       fe_workarea_add_tab         (GtkWidget *tab, const gchar *label);
 void       fe_workarea_activate_tab    (GtkWidget *tab);
 GtkWidget* fe_workarea_get_current_tab (void);
+void       fe_workarea_remove_tab      (GtkWidget *tab);
 
 /*
  * Global variables
@@ -63,6 +64,8 @@ extern GtkWidget*  glb_mainwin;
 #define GNOMEDB_FE_CONFIG_SECTION_MAIN "/gnomedb-fe"
 #define GNOMEDB_FE_CONFIG_SECTION_LOAD "/gnomedb-fe/Load"
 
+#define GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS "/gnomedb-fe/General/SaveWindowPos"
+
 END_GNOME_DECLS
 
 #endif
\ No newline at end of file
