@@ -2,19 +2,20 @@
  * Copyright (C) 2000 Rodrigo Moya
  * Copyright (C) 2000 Vivien Malerba
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #if !defined(__gnome_db_control_widget_h__)
@@ -56,6 +57,9 @@ gboolean   gnome_db_control_widget_is_alive   (GnomeDbControlWidget *wid);
 
 void       gnome_db_control_widget_activate   (GnomeDbControlWidget *wid);
 void       gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid);
+
+#define gnome_db_control_widget_get_repo_id(_wid_) ((_wid_) ? GNOME_DB_CONTROL_WIDGET((_wid_))->goad_id : NULL)
+
 /* 
  * Functions to manipulate controls from the properties 
  */
