@@ -1,19 +1,20 @@
 /* GNOME DB library
  * Copyright (C) 2000 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <gnome-db.h>
@@ -64,9 +65,9 @@ update_view_dialog (GnomeDialog *dialog, GtkCList *list, gint row)
   if (GTK_IS_ENTRY(w))
     {
       if (gtk_clist_get_text(list, row, 1, &str))
-	{
-	  gtk_entry_set_text(GTK_ENTRY(w), str);
-	}
+        {
+          gtk_entry_set_text(GTK_ENTRY(w), str);
+        }
     }
 
   /* update message */
@@ -74,11 +75,11 @@ update_view_dialog (GnomeDialog *dialog, GtkCList *list, gint row)
   if (GTK_IS_TEXT(w))
     {
       if (gtk_clist_get_text(list, row, 2, &str))
-	{
-	  gtk_editable_delete_text(GTK_EDITABLE(w), 0,
-				   gtk_text_get_length(GTK_TEXT(w)));
-	  gtk_text_insert(GTK_TEXT(w), NULL, NULL, NULL, str, strlen(str));
-	}
+        {
+          gtk_editable_delete_text(GTK_EDITABLE(w), 0,
+                                   gtk_text_get_length(GTK_TEXT(w)));
+          gtk_text_insert(GTK_TEXT(w), NULL, NULL, NULL, str, strlen(str));
+        }
     }
 
   /* update record label */
@@ -358,3 +359,36 @@ gnome_db_log_viewer_show_current (GnomeDbLogViewer *viewer)
       gtk_widget_show(dialog);
     }
 }
+
+/**
+ * gnome_db_log_viewer_save
+ */
+void
+gnome_db_log_viewer_save (GnomeDbLogViewer *viewer, const gchar *filename)
+{
+  gint  cnt;
+  FILE* fp;
+  
+  g_return_if_fail(GNOME_DB_IS_LOG_VIEWER(viewer));
+  g_return_if_fail(filename != NULL);
+  g_return_if_fail(GTK_IS_CLIST(viewer->msg_list));
+  
+  if ((fp = fopen(filename, "w")))
+    {
+      for (cnt = 0; cnt < GTK_CLIST(viewer->msg_list)->rows; cnt++)
+        {
+          gchar* date_str = NULL;
+          gchar* time_str = NULL;
+          gchar* msg_str = NULL;
+          
+          gtk_clist_get_text(GTK_CLIST(viewer->msg_list), cnt, 0, &date_str);
+          gtk_clist_get_text(GTK_CLIST(viewer->msg_list), cnt, 1, &time_str);
+          gtk_clist_get_text(GTK_CLIST(viewer->msg_list), cnt, 2, &msg_str);
+          fprintf(fp, "%s.%s: %s\n", date_str, time_str, msg_str);
+        }
+      fclose(fp);
+    }
+  else gnome_db_show_error(_("Could not create file %s"), filename);
+}
+
+
