@@ -1,26 +1,26 @@
 /* GNOME DB library
  * Copyright (C) 1999-2000 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
  
 #if !defined(_GNOME_DB_H_)
 #  define _GNOME_DB_H_
 
 #include <gnome.h>
-#include <libgnomeprint/gnome-printer.h>
 
 #include <gda-client.h>
 #include <gnome-db-component.h>
@@ -29,6 +29,7 @@
 #include <gnome-db-control-instance.h>
 #include <gnome-db-control.h>
 #include <gnome-db-embeddable.h>
+#include <gnome-db-moniker.h>
 
 #include <gnome-db-browser.h>
 #include <gnome-db-combo.h>
@@ -92,32 +93,6 @@ GtkWidget* gnome_db_new_toolbar_widget            (GtkOrientation orientation,
                                                    gpointer user_data);
 GtkWidget* gnome_db_new_tree_widget               (void);
 
-/*
- * Common dialogs
- */
-gchar* gnome_db_select_file   (const gchar *title);
-void   gnome_db_show_error    (const gchar *, ...);
-void   gnome_db_show_file     (const gchar *);
-void   gnome_db_submit_bug_cb (GtkWidget *w, gpointer data);
-
-/*
- * Utility functions (private use)
- */
-void         gnome_db_clear_clist        (GtkCList *);
-GnomePixmap* gnome_db_get_pixmap         (const gchar *stock_pixmap);
-GtkWidget*   gnome_db_new_popup_menu     (GtkWidget *, GnomeUIInfo *, gpointer );
-void         gnome_db_show_about_dialog  (const gchar *title);
-void         gnome_db_set_bg_color       (GtkWidget *w, gint red, gint green, gint blue);
-
-void         gnome_db_load_window_config (const gchar *name, GtkWidget *window);
-void         gnome_db_save_window_config (const gchar *name, GtkWidget *window);
-
-/*
- * Printing support
- */
-void          gnome_db_print_setup_dlg_cb (GtkWidget *w, gpointer data);
-GnomePrinter* gnome_db_print_get_printer  (void);
-
 /*
  * Repo IDs of the different GNOME-DB components
  */
@@ -136,14 +111,20 @@ GnomePrinter* gnome_db_print_get_printer  (void);
 #define GNOME_DB_OAFIID_HELP_VIEWER "OAFIID:control:gnome-db-help-viewer:a792ef6d-162e-4846-96d9-8c0eda62f965"
 #define GNOME_DB_OAFIID_DESIGNER    "OAFIID:control:gnome-db-designer:a85a2539-19e2-46fb-8cd4-fc2ddb03b034"
 
+#define GNOME_DB_OAFIID_MONIKER_DATABASE_FACTORY "OAFIID:DatabaseMonikerFactory:70a47938-d4cd-4fae-a80b-699416dffba7"
+#define GNOME_DB_OAFIID_MONIKER_DATABASE         "OAFIID:DatabaseMoniker:70a47938-d4cd-4fae-a80b-699416dffba7"
+
 /*
  * Configuration sections
  */
 #define GNOME_DB_CONFIG_SECTION_DESIGNER         "/gnome-db/Designer"
 #define GNOME_DB_CONFIG_SECTION_HELP_VIEWER      "/gnome-db/HelpViewer"
+#define GNOME_DB_CONFIG_SECTION_HELP_VIEWER_DOCS "/gnome-db/HelpViewer/Docs"
 #define GNOME_DB_CONFIG_SECTION_LAST_CONNECTIONS "/gnome-db/LastConnections"
 #define GNOME_DB_CONFIG_SECTION_LAST_COMMANDS    "/gnome-db/LastCommands"
 
+#define GNOME_DB_CONFIG_KEY_HELP_VIEWER_HOME "/gnome-db/HelpViewer/Home"
+
 END_GNOME_DECLS
 
 #endif
